import 'dart:async';
import 'package:call_log/call_log.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_background_service/flutter_background_service.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:get/get_navigation/src/root/get_material_app.dart';
import 'package:project_telephony/ui/login/login_page.dart';

import 'package:telephony/telephony.dart';

onBackgroundMessage(SmsMessage message) {
  debugPrint("onBackgroundMessage called");
}

Future<void> main() async {
  WidgetsFlutterBinding.ensureInitialized();
  await initializeService();
  runApp(const MyApp());
  SystemUiOverlayStyle systemUiOverlayStyle = const SystemUiOverlayStyle(
      statusBarColor: Colors.transparent, //状态栏背景色
      statusBarIconBrightness: Brightness.dark); //状态栏字体颜色
}

Future<void> initializeService() async {
  final service = FlutterBackgroundService();
  await service.configure(
    androidConfiguration: AndroidConfiguration(
      onStart: onStart,
      autoStart: true,
      isForegroundMode: true,
    ),
    iosConfiguration: IosConfiguration(
      autoStart: true,
      onForeground: onStart,
      onBackground: onIosBackground,
    ),
  );
}

void onIosBackground() {
  WidgetsFlutterBinding.ensureInitialized();
  // print('FLUTTER BACKGROUND FETCH');
}

void onStart() {
  int flag = 0;
  String? phoneNum, callState;
  WidgetsFlutterBinding.ensureInitialized();

  Timer.periodic(const Duration(seconds: 1), (timer) async {
    CallState state = await Telephony.instance.callState;
    callState = state.name;
    // print(callState!+"$flag");
    if (callState == "IDLE") {
      if (flag != 0) {
        flag = 0;
        final Iterable<CallLogEntry> result = await CallLog.query();
        phoneNum = result.first.number;
        // print(phoneNum);
        Phone.telephony.sendSms(
          to: phoneNum!,
          message: "hello",
          isMultipart: true,
        );
      }
    } else if (callState == "RINGING") {
      flag++;
    } else if (callState == "OFFHOOK") {
      flag++;
    }
  });
}

class Phone {
  static Telephony telephony = Telephony.instance;
}

class MyApp extends StatefulWidget {
  const MyApp({Key? key}) : super(key: key);

  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  String _message = "";

  @override
  void initState() {
    super.initState();
    final service = FlutterBackgroundService();
    // JPush jPush=JPush();
    // jPush.setup(
    //   appKey: "",
    //   channel: "theChannel",
    //     production: false,
    //     debug: true
    // );
    service.start();
  }

  onMessage(SmsMessage message) async {
    setState(() {
      _message = message.body ?? "Error reading message body.";
    });
  }

  onSendStatus(SendStatus status) {
    setState(() {
      _message = status == SendStatus.SENT ? "sent" : "delivered";
    });
  }

  Future<void> initPlatformState() async {
    final bool? result = await Phone.telephony.requestPhoneAndSmsPermissions;
    if (result != null && result) {
      Phone.telephony.listenIncomingSms(
          onNewMessage: onMessage, onBackgroundMessage: onBackgroundMessage);
    }
    if (!mounted) return;
  }

  @override
  Widget build(BuildContext context) {
    return MediaQuery(
        data: MediaQueryData.fromWindow(WidgetsBinding.instance!.window),
        child: ScreenUtilInit(
          designSize: const Size(750, 1334),
          builder: (context, child) {
            return const AnnotatedRegion<SystemUiOverlayStyle>(
                value: SystemUiOverlayStyle(
                    statusBarColor: Colors.transparent, //状态栏背景色
                    statusBarIconBrightness: Brightness.dark),
                child: GetMaterialApp(
                  // get.testmode=true,
                  debugShowCheckedModeBanner: false,
                  home: LoginPage(),
                  // supportedLocales: [Locale('zh')],
                  // locale: Locale('zh'),
                  // builder: ( context,child){
                  //   ScreenUtil.setContext(context);
                  //   return MediaQuery(
                  //     //设置文字大小不随系统设置改变
                  //     data: MediaQuery.of(context).copyWith(textScaleFactor: 1.0),
                  //     // child: BotToastInit().call(context, child),
                  //   );
                  // },
                ));
          },
        ));
  }
}
